@@ -13,12 +13,8 @@
 #' @author Dan Chaltiel
 #' @export
 #' @importFrom checkmate assert_class vname
-#' @importFrom stringr str_remove
+#' @importFrom cli cli_warn
 #' @importFrom rlang check_installed
-#' @importFrom purrr walk
-#' @importFrom tidyr replace_na
-#' @importFrom dplyr %>% mutate across everything any_of lag lead select
-#' @importFrom glue glue
 #'
 #' @examples
 #' library(openxlsx)
@@ -70,6 +66,10 @@ as_workbook = function(x, show_test_name=TRUE,
 
 #' @keywords internal
 #' @noRd
+#' @importFrom dplyr across any_of everything lead mutate select
+#' @importFrom purrr map walk
+#' @importFrom stringr str_remove
+#' @importFrom tidyr replace_na
 addToWorksheet = function(wb, ct, sheetname, show_test_name = TRUE,
                           by_header = NULL, keep_id = FALSE,
                           generic_labels=list(id = ".id", variable = "variable", value = "value",
@@ -96,7 +96,7 @@ addToWorksheet = function(wb, ct, sheetname, show_test_name = TRUE,
     ct[[test]] = str_remove(ct[[test]], "\\n\\(.*\\)")
   }
 
-  rtn = ct %>% mutate(across(everything(), replace_na, replace="NA"))
+  rtn = ct %>% mutate(across(everything(), ~replace_na(.x, replace="NA")))
   sep.rows = which(rtn[[id]] != lead(rtn[[id]]))
 
   if(keep_id) {
@@ -162,4 +162,3 @@ addToWorksheet = function(wb, ct, sheetname, show_test_name = TRUE,
   openxlsx::setColWidths(wb, sheet=sheetname, cols = 1:col_right, widths = "auto")
   wb
 }
-
